@@ -103,7 +103,10 @@ class MongoAlchemy(object):
             raise ImproperlyConfiguredError("You should provide a database name (the MONGOALCHEMY_DATABASE setting).")
 
         uri = _get_mongo_uri(app)
-        self.session = session.Session.connect(app.config.get('MONGOALCHEMY_DATABASE'), host=uri)
+        self.session = session.Session.connect(app.config.get('MONGOALCHEMY_DATABASE'),
+                                               host=uri,
+                                               )
+        self.session.safe = app.config.get('MONGOALCHEMY_SAFE_SESSION', False)
         self.Document._session = self.session
 
 class Pagination(object):
@@ -247,9 +250,13 @@ class Document(document.Document):
         self._session.insert(self)
         self._session.flush()
 
-    def remove(self):
-        """Removes the document itself from database."""
-        self._session.remove(self)
+    def remove(self, safe=None):
+        """Removes the document itself from database.
+
+        The optional ``safe`` argument is a boolean that specifies if the
+        remove method should wait for the operation to complete.
+        """
+        self._session.remove(self, safe=None)
         self._session.flush()
 
     def __cmp__(self, other):
